appGUI: Graphical User Interface

Description Usage Value Examples

View source: R/shiny.R

Description

Runs a Graphical User Interface to evaluate the projects for Global CO2 emission analysis app. This app is presented the amount of worldwide CO2 emission of from 1960 to 2020. It is possible to select different countries to see the details. Besides, the prediction for the next few years is also provided. The data set is collected from Data World Bank. By moving the Year slidebar, it will change the number of observations year by year.

Usage

1

Value

shiny app

Examples

1
2
3
4
## Not run: 
appGUI()

## End(Not run)

unimi-dse/2fd51b52 documentation built on Feb. 20, 2020, 8:58 a.m.