plotData: Data plotting

Description Usage Arguments Value

View source: R/plotData.R

Description

Plot data

Usage

1
plotData(tsdata, forecastData = NULL, plotTit, fc)

Arguments

tsdata

time Series object. Object contains year observations and statistics about CO2 emission worldwide.

forecastData

forecasting time series. This data are calculated by forecast. NULL by default

plotTit

character string The title of the plot that can be changed by selecting different country uiSelectInput

fc

boolean. Passing argument TRUE if user check to checkbox for forecasting, else FALSE

Value

plotly


unimi-dse/2fd51b52 documentation built on Feb. 20, 2020, 8:58 a.m.