Description Usage Arguments Value
Plot data
1 |
tsdata |
time Series object. Object contains year observations and statistics about CO2 emission worldwide. |
forecastData |
forecasting time series. This data are calculated by forecast. NULL by default |
plotTit |
character string The title of the plot that can be changed by selecting different country uiSelectInput |
fc |
boolean. Passing argument TRUE if user check to checkbox for forecasting, else FALSE |
plotly
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.